/******************************************************************************
 *
 * File:        controller.h
 *
 * Description: This file contains the declaration of the Controller class.
 *
 * Copyright (C) 2023 CrossControl AB
 * All rights reserved.
 * Contact: CrossControl AB (info@crosscontrol.com)
 *
 * Code Template Revision: 1.2
 *
 ******************************************************************************/

/******************************************************************************
 * Nesting Header
 ******************************************************************************/
#ifndef CONTROLLER_H
#define CONTROLLER_H

/******************************************************************************
 * Include Files
 ******************************************************************************/
#include <QObject>
#include <QString>
#include <QtQml/qqmlregistration.h>

namespace WindowManager {
namespace Core {

    /******************************************************************************
     * Class Declaration
     ******************************************************************************/
    /**
     * @brief The Controller class is used to control the state of process by using
     * using the C++ POSIX standard.
     */
    class Controller : public QObject
    {
        Q_OBJECT

    public:
        /**
         * @brief Default constructor of the class
         */
        Controller(QObject *parent = nullptr);

        /**
         * @brief Constructor to control a specific process
         * @param pid The PID of the process
         * @param execPath Absolute path to the binary
         * @param parent The parent owning the controller object
         */
        Controller(uint pid, QString execPath, QObject *parent = nullptr);

        /**
         * @brief Start a new instance of the binary
         */
        uint startClient(QString client, QStringList arguments);

        /**
         * @brief Quit the process
         */
        int quitClient();

        /**
         * @brief Terminate the process
         */
        int terminateClient();

        /**
         * @brief Pause the process
         */
        int pauseClient();

        /**
         * @brief Resume the process
         */
        int resumeClient();

    private:
        uint m_pid;
        QString m_execPath;
    };

} // Core
} // WindowManager

#endif // CONTROLLER_H
